==> jc-1.4.0.tar.gz: javax/swing/Box__24Filler__24AccessibleBoxFiller.c <==
// public class javax.swing.Box$Filler$AccessibleBoxFiller

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 13eec6fc3dc83b49 javax_accessibility_AccessibleRole
// @dep_class 5c9b4f50df9958c7 javax_swing_Box__24Filler
// @dep_class 8cbec6b4bd9e30b1 javax_swing_Box__24Filler__24AccessibleBoxFiller

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_accessibility_AccessibleRole
// @dep_header javax_swing_Box__24Filler
// @dep_header javax_swing_Box__24Filler__24AccessibleBoxFiller

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/accessibility/AccessibleRole.h"
#include "javax/swing/Box__24Filler.h"
#include "javax/swing/Box__24Filler__24AccessibleBoxFiller.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final long serialVersionUID
static const jlong _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$initial_value$serialVersionUID = _JC_JLONG(164963348357479321);
static _jc_field _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$field_info$serialVersionUID = {
	.name=		"serialVersionUID",
	.signature=	"J",
	.class=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type,
	.type=		&_jc_long$prim$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields_struct, serialVersionUID),
	.initial_value=	&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$initial_value$serialVersionUID,
};

// final javax.swing.Box$Filler this
static _jc_field _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$field_info$this = {
	.name=		"this",
	.signature=	"Ljavax/swing/Box$Filler;",
	.class=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type,
	.type=		&_jc_javax_swing_Box__24Filler$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object, refs[-1].javax_swing_Box__24Filler__24AccessibleBoxFiller.this),
};

// Fields
static _jc_field *const _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields[] = {
	&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$field_info$serialVersionUID,
	&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$field_info$this
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>(javax.swing.Box$Filler)
//

static _jc_linenum _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$linenum_table$_init$c3ce195336b3e4d6[];

static const unsigned char _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$param_ptypes$_init$c3ce195336b3e4d6[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$param_types$_init$c3ce195336b3e4d6[] = {
	&_jc_javax_swing_Box__24Filler$type
};

_jc_method _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method_info$_init$c3ce195336b3e4d6 = {
	.name=			"<init>",
	.signature=		"(Ljavax/swing/Box$Filler;)V",
	.class=			&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type,
	.param_types=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$param_types$_init$c3ce195336b3e4d6,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$param_ptypes$_init$c3ce195336b3e4d6,
	.signature_hash=	_JC_JLONG(0xc3ce195336b3e4d6),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$_init$c3ce195336b3e4d6,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$linenum_table$_init$c3ce195336b3e4d6
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_Box__24Filler__24AccessibleBoxFiller, _init$c3ce195336b3e4d6);

void
_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$_init$c3ce195336b3e4d6(_jc_env *const env, _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *this, _jc_javax_swing_Box__24Filler$object *param0)
{
	struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *r0;
	struct _jc_javax_swing_Box__24Filler$object *r1;

	r0 = this;
	r1 = param0;
	_JC_REF_FIELD(env, r0, javax_swing_Box__24Filler__24AccessibleBoxFiller, this) = r1;
	_JC_LINE_NUMBER(92);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public javax.accessibility.AccessibleRole getAccessibleRole()
//

static _jc_linenum _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$linenum_table$getAccessibleRole$eaa05a502d0ede18[];

static const unsigned char _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$param_ptypes$getAccessibleRole$eaa05a502d0ede18[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method_info$getAccessibleRole$eaa05a502d0ede18 = {
	.name=			"getAccessibleRole",
	.signature=		"()Ljavax/accessibility/AccessibleRole;",
	.class=			&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type,
	.return_type=		&_jc_javax_accessibility_AccessibleRole$type,
	.param_ptypes=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$param_ptypes$getAccessibleRole$eaa05a502d0ede18,
	.signature_hash=	_JC_JLONG(0xeaa05a502d0ede18),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$getAccessibleRole$eaa05a502d0ede18,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtable, javax_swing_Box__24Filler__24AccessibleBoxFiller.getAccessibleRole$eaa05a502d0ede18) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$linenum_table$getAccessibleRole$eaa05a502d0ede18
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_Box__24Filler__24AccessibleBoxFiller, getAccessibleRole$eaa05a502d0ede18);

_jc_javax_accessibility_AccessibleRole$object *
_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *const env, _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *this)
{
	struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(96);				// 0
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$methods[] = {
	&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method_info$_init$c3ce195336b3e4d6,
	&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method_info$getAccessibleRole$eaa05a502d0ede18
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields_struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$instanceof_hash_bucket_49[] = {
	&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[49]=	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$instanceof_hash_bucket_49,
	[113]=	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/accessibility/AccessibleRole",	_JC_JLONG(0x13eec6fc3dc83b49) },
	{ "javax/swing/Box$Filler",	_JC_JLONG(0x5c9b4f50df9958c7) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtype _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type = {
    .type= {
	.name=			"javax/swing/Box$Filler$AccessibleBoxFiller",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x8cbec6b4bd9e30b1),
		.source_file=		"Box.java",
		.instance_size=		sizeof(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$refs) + sizeof(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields) / sizeof(*_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields),
		.fields=		_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields,
		.num_methods=		sizeof(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$methods) / sizeof(*_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$methods),
		.methods=		_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$methods,
		.instanceof_hash_table=	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$instanceof_hash_table,
		.class_fields=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_fields,
		.outer_class=		&_jc_javax_swing_Box__24Filler$type,
		.num_class_depends=		sizeof(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_depends) / sizeof(*_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_depends),
		.class_depends=		_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_Box__24Filler__24AccessibleBoxFiller= {
	    .getAccessibleRole$eaa05a502d0ede18=
		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$getAccessibleRole$eaa05a502d0ede18,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/swing/Box__24Filler__24AccessibleBoxFiller.c <==
// public class javax.swing.Box$Filler$AccessibleBoxFiller

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 13eec6fc3dc83b49 javax_accessibility_AccessibleRole
// @dep_class 5c9b4f50df9958c7 javax_swing_Box__24Filler
// @dep_class 8cbec6b4bd9e30b1 javax_swing_Box__24Filler__24AccessibleBoxFiller

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_accessibility_AccessibleRole
// @dep_header javax_swing_Box__24Filler
// @dep_header javax_swing_Box__24Filler__24AccessibleBoxFiller

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/accessibility/AccessibleRole.h"
#include "javax/swing/Box__24Filler.h"
#include "javax/swing/Box__24Filler__24AccessibleBoxFiller.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final long serialVersionUID
static const jlong _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$initial_value$serialVersionUID = _JC_JLONG(164963348357479321);
static _jc_field _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$field_info$serialVersionUID = {
	.name=		"serialVersionUID",
	.signature=	"J",
	.class=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type,
	.type=		&_jc_long$prim$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields_struct, serialVersionUID),
	.initial_value=	&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$initial_value$serialVersionUID,
};

// final javax.swing.Box$Filler this
static _jc_field _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$field_info$this = {
	.name=		"this",
	.signature=	"Ljavax/swing/Box$Filler;",
	.class=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type,
	.type=		&_jc_javax_swing_Box__24Filler$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object, refs[-1].javax_swing_Box__24Filler__24AccessibleBoxFiller.this),
};

// Fields
static _jc_field *const _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields[] = {
	&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$field_info$serialVersionUID,
	&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$field_info$this
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>(javax.swing.Box$Filler)
//

static _jc_linenum _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$linenum_table$_init$c3ce195336b3e4d6[];

static const unsigned char _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$param_ptypes$_init$c3ce195336b3e4d6[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$param_types$_init$c3ce195336b3e4d6[] = {
	&_jc_javax_swing_Box__24Filler$type
};

_jc_method _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method_info$_init$c3ce195336b3e4d6 = {
	.name=			"<init>",
	.signature=		"(Ljavax/swing/Box$Filler;)V",
	.class=			&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type,
	.param_types=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$param_types$_init$c3ce195336b3e4d6,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$param_ptypes$_init$c3ce195336b3e4d6,
	.signature_hash=	_JC_JLONG(0xc3ce195336b3e4d6),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$_init$c3ce195336b3e4d6,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$linenum_table$_init$c3ce195336b3e4d6
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_Box__24Filler__24AccessibleBoxFiller, _init$c3ce195336b3e4d6);

void _JC_JCNI_ATTR
_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$_init$c3ce195336b3e4d6(_jc_env *const env, _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *this, _jc_javax_swing_Box__24Filler$object *param0)
{
	struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *r0;
	struct _jc_javax_swing_Box__24Filler$object *r1;

	r0 = this;
	r1 = param0;
	_JC_REF_FIELD(env, r0, javax_swing_Box__24Filler__24AccessibleBoxFiller, this) = r1;
	_JC_LINE_NUMBER(92);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public javax.accessibility.AccessibleRole getAccessibleRole()
//

static _jc_linenum _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$linenum_table$getAccessibleRole$eaa05a502d0ede18[];

static const unsigned char _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$param_ptypes$getAccessibleRole$eaa05a502d0ede18[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method_info$getAccessibleRole$eaa05a502d0ede18 = {
	.name=			"getAccessibleRole",
	.signature=		"()Ljavax/accessibility/AccessibleRole;",
	.class=			&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type,
	.return_type=		&_jc_javax_accessibility_AccessibleRole$type,
	.param_ptypes=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$param_ptypes$getAccessibleRole$eaa05a502d0ede18,
	.signature_hash=	_JC_JLONG(0xeaa05a502d0ede18),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$getAccessibleRole$eaa05a502d0ede18,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtable, javax_swing_Box__24Filler__24AccessibleBoxFiller.getAccessibleRole$eaa05a502d0ede18) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$linenum_table$getAccessibleRole$eaa05a502d0ede18
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_Box__24Filler__24AccessibleBoxFiller, getAccessibleRole$eaa05a502d0ede18);

_jc_javax_accessibility_AccessibleRole$object * _JC_JCNI_ATTR
_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *const env, _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *this)
{
	struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(96);				// 0
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$methods[] = {
	&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method_info$_init$c3ce195336b3e4d6,
	&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method_info$getAccessibleRole$eaa05a502d0ede18
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields_struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$instanceof_hash_bucket_49[] = {
	&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[49]=	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$instanceof_hash_bucket_49,
	[101]=	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/accessibility/AccessibleRole",	_JC_JLONG(0x13eec6fc3dc83b49) },
	{ "javax/swing/Box$Filler",	_JC_JLONG(0x5c9b4f50df9958c7) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtype _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type = {
    .type= {
	.name=			"javax/swing/Box$Filler$AccessibleBoxFiller",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x8cbec6b4bd9e30b1),
		.source_file=		"Box.java",
		.instance_size=		sizeof(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$refs) + sizeof(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields) / sizeof(*_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields),
		.fields=		_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields,
		.num_methods=		sizeof(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$methods) / sizeof(*_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$methods),
		.methods=		_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$methods,
		.instanceof_hash_table=	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$instanceof_hash_table,
		.class_fields=		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_fields,
		.outer_class=		&_jc_javax_swing_Box__24Filler$type,
		.num_class_depends=		sizeof(_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_depends) / sizeof(*_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_depends),
		.class_depends=		_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_Box__24Filler__24AccessibleBoxFiller= {
	    .getAccessibleRole$eaa05a502d0ede18=
		&_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$getAccessibleRole$eaa05a502d0ede18,
	},
    }
};
